import type { BasicColumn, FormProps } from '@/components/Table'

export interface Option {
    label: string
    value: string
    property?: {
        driver?: string
        url?: string
        username?: string
    }
    disabled?: boolean
}

/**
 * 支持的数据源类型
 */
export const options: Option[] = [
    {
        label: 'PostgreSQL',
        value: 'PostgreSQL',
        property: {
            driver: 'org.postgresql.Driver',
            url: 'jdbc:postgresql://127.0.0.1:5432/basic-boot',
            username: 'postgres',
        },
    },
    {
        label: 'H2',
        value: 'H2',
        property: {
            driver: 'org.h2.Driver',
            url: 'jdbc:h2:file:~/h2_basic;DB_CLOSE_ON_EXIT=FALSE',
            username: 'sa',
        },
    },
    {
        label: 'MySQL 8.x',
        value: 'MySQL',
        property: {
            driver: 'com.mysql.cj.jdbc.Driver',
            url: 'jdbc:mysql://127.0.0.1:3306/basic-boot?characterEncoding=UTF-8&useUnicode=true&useSSL=false&tinyInt1isBit=false&allowPublicKeyRetrieval=true&serverTimezone=Asia/Shanghai',
            username: 'root',
        },
        disabled: true,
    },
    {
        label: '其他数据库',
        value: 'custom',
    },
]

// ================================
export function getColumns(): BasicColumn[] {
    return [
        {
            title: '数据源名称',
            dataIndex: 'name',
            width: 180,
        },
        {
            title: '数据库类型',
            dataIndex: 'type',
            width: 150,
        },
        {
            title: '驱动类',
            dataIndex: 'driver',
        },
        {
            title: '数据源地址',
            dataIndex: 'url',
        },
        {
            title: '用户名',
            dataIndex: 'username',
            width: 150,
        },
        {
            title: '创建时间',
            dataIndex: 'createTime',
            defaultHidden: true,
            width: 180,
        },
    ]
}
export function getDataSource() {
    return (() => {
        const data = []

        data.push({
            id: '1',
            name: 'PostgreSQL 14',
            type: 'PostgreSQL',
            driver: 'org.postgresql.Driver',
            url: 'jdbc:postgresql://127.0.0.1:5432/basic-boot',
            username: 'postgres',
            password: 'postgres',
            createTime: '2023-02-26 15:36:01',
        })

        return data
    })()
}
export function getFormConfig(): Partial<FormProps> {
    return {
        layout: 'inline',
        name: 'query',
        colon: true,
        compact: true,
        schemas: [
            {
                field: `name`,
                label: `数据源名称`,
                component: 'Input',
            },
            {
                field: `type`,
                label: `数据库类型`,
                component: 'Select',
                componentProps: {
                    options,
                    style: {
                        width: '180px',
                    },
                },
            },
        ],
        showAdvancedButton: false,
        submitButtonOptions: {
            preIcon: 'material-symbols:search',
        },
    }
}
